==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/GitpodOptions.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Constructor options for the Gitpod component.
 * <p>
 * By default, Gitpod uses the 'gitpod/workspace-full' docker image.
 * <p>
 * @see https://github.com/gitpod-io/workspace-images/blob/master/full/Dockerfile
 * By default, all tasks will be run in parallel. To run the tasks in sequence,
 * create a new task and specify the other tasks as subtasks.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.399Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.GitpodOptions")
@software.amazon.jsii.Jsii.Proxy(GitpodOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GitpodOptions extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.DevEnvironmentOptions {

    /**
     * (experimental) Optional Gitpod's Github App integration for prebuilds If this is not set and Gitpod's Github App is installed, then Gitpod will apply these defaults: https://www.gitpod.io/docs/prebuilds/#configure-the-github-app.
     * <p>
     * Default: undefined
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.GitpodPrebuilds getPrebuilds() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GitpodOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GitpodOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GitpodOptions> {
        io.github.cdklabs.projen.GitpodPrebuilds prebuilds;
        io.github.cdklabs.projen.DevEnvironmentDockerImage dockerImage;
        java.util.List<java.lang.String> ports;
        java.util.List<io.github.cdklabs.projen.Task> tasks;
        java.util.List<java.lang.String> vscodeExtensions;

        /**
         * Sets the value of {@link GitpodOptions#getPrebuilds}
         * @param prebuilds Optional Gitpod's Github App integration for prebuilds If this is not set and Gitpod's Github App is installed, then Gitpod will apply these defaults: https://www.gitpod.io/docs/prebuilds/#configure-the-github-app.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder prebuilds(io.github.cdklabs.projen.GitpodPrebuilds prebuilds) {
            this.prebuilds = prebuilds;
            return this;
        }

        /**
         * Sets the value of {@link GitpodOptions#getDockerImage}
         * @param dockerImage A Docker image or Dockerfile for the container.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dockerImage(io.github.cdklabs.projen.DevEnvironmentDockerImage dockerImage) {
            this.dockerImage = dockerImage;
            return this;
        }

        /**
         * Sets the value of {@link GitpodOptions#getPorts}
         * @param ports An array of ports that should be exposed from the container.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ports(java.util.List<java.lang.String> ports) {
            this.ports = ports;
            return this;
        }

        /**
         * Sets the value of {@link GitpodOptions#getTasks}
         * @param tasks An array of tasks that should be run when the container starts.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder tasks(java.util.List<? extends io.github.cdklabs.projen.Task> tasks) {
            this.tasks = (java.util.List<io.github.cdklabs.projen.Task>)tasks;
            return this;
        }

        /**
         * Sets the value of {@link GitpodOptions#getVscodeExtensions}
         * @param vscodeExtensions An array of extension IDs that specify the extensions that should be installed inside the container when it is created.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder vscodeExtensions(java.util.List<java.lang.String> vscodeExtensions) {
            this.vscodeExtensions = vscodeExtensions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GitpodOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GitpodOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GitpodOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GitpodOptions {
        private final io.github.cdklabs.projen.GitpodPrebuilds prebuilds;
        private final io.github.cdklabs.projen.DevEnvironmentDockerImage dockerImage;
        private final java.util.List<java.lang.String> ports;
        private final java.util.List<io.github.cdklabs.projen.Task> tasks;
        private final java.util.List<java.lang.String> vscodeExtensions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.prebuilds = software.amazon.jsii.Kernel.get(this, "prebuilds", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.GitpodPrebuilds.class));
            this.dockerImage = software.amazon.jsii.Kernel.get(this, "dockerImage", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DevEnvironmentDockerImage.class));
            this.ports = software.amazon.jsii.Kernel.get(this, "ports", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.tasks = software.amazon.jsii.Kernel.get(this, "tasks", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class)));
            this.vscodeExtensions = software.amazon.jsii.Kernel.get(this, "vscodeExtensions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.prebuilds = builder.prebuilds;
            this.dockerImage = builder.dockerImage;
            this.ports = builder.ports;
            this.tasks = (java.util.List<io.github.cdklabs.projen.Task>)builder.tasks;
            this.vscodeExtensions = builder.vscodeExtensions;
        }

        @Override
        public final io.github.cdklabs.projen.GitpodPrebuilds getPrebuilds() {
            return this.prebuilds;
        }

        @Override
        public final io.github.cdklabs.projen.DevEnvironmentDockerImage getDockerImage() {
            return this.dockerImage;
        }

        @Override
        public final java.util.List<java.lang.String> getPorts() {
            return this.ports;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.Task> getTasks() {
            return this.tasks;
        }

        @Override
        public final java.util.List<java.lang.String> getVscodeExtensions() {
            return this.vscodeExtensions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getPrebuilds() != null) {
                data.set("prebuilds", om.valueToTree(this.getPrebuilds()));
            }
            if (this.getDockerImage() != null) {
                data.set("dockerImage", om.valueToTree(this.getDockerImage()));
            }
            if (this.getPorts() != null) {
                data.set("ports", om.valueToTree(this.getPorts()));
            }
            if (this.getTasks() != null) {
                data.set("tasks", om.valueToTree(this.getTasks()));
            }
            if (this.getVscodeExtensions() != null) {
                data.set("vscodeExtensions", om.valueToTree(this.getVscodeExtensions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.GitpodOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GitpodOptions.Jsii$Proxy that = (GitpodOptions.Jsii$Proxy) o;

            if (this.prebuilds != null ? !this.prebuilds.equals(that.prebuilds) : that.prebuilds != null) return false;
            if (this.dockerImage != null ? !this.dockerImage.equals(that.dockerImage) : that.dockerImage != null) return false;
            if (this.ports != null ? !this.ports.equals(that.ports) : that.ports != null) return false;
            if (this.tasks != null ? !this.tasks.equals(that.tasks) : that.tasks != null) return false;
            return this.vscodeExtensions != null ? this.vscodeExtensions.equals(that.vscodeExtensions) : that.vscodeExtensions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.prebuilds != null ? this.prebuilds.hashCode() : 0;
            result = 31 * result + (this.dockerImage != null ? this.dockerImage.hashCode() : 0);
            result = 31 * result + (this.ports != null ? this.ports.hashCode() : 0);
            result = 31 * result + (this.tasks != null ? this.tasks.hashCode() : 0);
            result = 31 * result + (this.vscodeExtensions != null ? this.vscodeExtensions.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/GitpodOptions.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Constructor options for the Gitpod component.
 * <p>
 * By default, Gitpod uses the 'gitpod/workspace-full' docker image.
 * <p>
 * @see <a href="https://github.com/gitpod-io/workspace-images/blob/master/full/Dockerfile
 * By default, all tasks will be run in parallel. To run the tasks in sequence,
 * create a new task and specify the other tasks as subtasks.">https://github.com/gitpod-io/workspace-images/blob/master/full/Dockerfile
 * By default, all tasks will be run in parallel. To run the tasks in sequence,
 * create a new task and specify the other tasks as subtasks.</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.101Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.GitpodOptions")
@software.amazon.jsii.Jsii.Proxy(GitpodOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GitpodOptions extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.DevEnvironmentOptions {

    /**
     * (experimental) Optional Gitpod's Github App integration for prebuilds If this is not set and Gitpod's Github App is installed, then Gitpod will apply these defaults: https://www.gitpod.io/docs/prebuilds/#configure-the-github-app.
     * <p>
     * Default: undefined
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.GitpodPrebuilds getPrebuilds() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GitpodOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GitpodOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<GitpodOptions> {
        io.github.cdklabs.projen.GitpodPrebuilds prebuilds;
        io.github.cdklabs.projen.DevEnvironmentDockerImage dockerImage;
        java.util.List<java.lang.String> ports;
        java.util.List<io.github.cdklabs.projen.Task> tasks;
        java.util.List<java.lang.String> vscodeExtensions;

        /**
         * Sets the value of {@link GitpodOptions#getPrebuilds}
         * @param prebuilds Optional Gitpod's Github App integration for prebuilds If this is not set and Gitpod's Github App is installed, then Gitpod will apply these defaults: https://www.gitpod.io/docs/prebuilds/#configure-the-github-app.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder prebuilds(io.github.cdklabs.projen.GitpodPrebuilds prebuilds) {
            this.prebuilds = prebuilds;
            return this;
        }

        /**
         * Sets the value of {@link GitpodOptions#getDockerImage}
         * @param dockerImage A Docker image or Dockerfile for the container.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dockerImage(io.github.cdklabs.projen.DevEnvironmentDockerImage dockerImage) {
            this.dockerImage = dockerImage;
            return this;
        }

        /**
         * Sets the value of {@link GitpodOptions#getPorts}
         * @param ports An array of ports that should be exposed from the container.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder ports(java.util.List<java.lang.String> ports) {
            this.ports = ports;
            return this;
        }

        /**
         * Sets the value of {@link GitpodOptions#getTasks}
         * @param tasks An array of tasks that should be run when the container starts.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder tasks(java.util.List<? extends io.github.cdklabs.projen.Task> tasks) {
            this.tasks = (java.util.List<io.github.cdklabs.projen.Task>)tasks;
            return this;
        }

        /**
         * Sets the value of {@link GitpodOptions#getVscodeExtensions}
         * @param vscodeExtensions An array of extension IDs that specify the extensions that should be installed inside the container when it is created.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder vscodeExtensions(java.util.List<java.lang.String> vscodeExtensions) {
            this.vscodeExtensions = vscodeExtensions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GitpodOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public GitpodOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GitpodOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GitpodOptions {
        private final io.github.cdklabs.projen.GitpodPrebuilds prebuilds;
        private final io.github.cdklabs.projen.DevEnvironmentDockerImage dockerImage;
        private final java.util.List<java.lang.String> ports;
        private final java.util.List<io.github.cdklabs.projen.Task> tasks;
        private final java.util.List<java.lang.String> vscodeExtensions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.prebuilds = software.amazon.jsii.Kernel.get(this, "prebuilds", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.GitpodPrebuilds.class));
            this.dockerImage = software.amazon.jsii.Kernel.get(this, "dockerImage", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DevEnvironmentDockerImage.class));
            this.ports = software.amazon.jsii.Kernel.get(this, "ports", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.tasks = software.amazon.jsii.Kernel.get(this, "tasks", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class)));
            this.vscodeExtensions = software.amazon.jsii.Kernel.get(this, "vscodeExtensions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.prebuilds = builder.prebuilds;
            this.dockerImage = builder.dockerImage;
            this.ports = builder.ports;
            this.tasks = (java.util.List<io.github.cdklabs.projen.Task>)builder.tasks;
            this.vscodeExtensions = builder.vscodeExtensions;
        }

        @Override
        public final io.github.cdklabs.projen.GitpodPrebuilds getPrebuilds() {
            return this.prebuilds;
        }

        @Override
        public final io.github.cdklabs.projen.DevEnvironmentDockerImage getDockerImage() {
            return this.dockerImage;
        }

        @Override
        public final java.util.List<java.lang.String> getPorts() {
            return this.ports;
        }

        @Override
        public final java.util.List<io.github.cdklabs.projen.Task> getTasks() {
            return this.tasks;
        }

        @Override
        public final java.util.List<java.lang.String> getVscodeExtensions() {
            return this.vscodeExtensions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getPrebuilds() != null) {
                data.set("prebuilds", om.valueToTree(this.getPrebuilds()));
            }
            if (this.getDockerImage() != null) {
                data.set("dockerImage", om.valueToTree(this.getDockerImage()));
            }
            if (this.getPorts() != null) {
                data.set("ports", om.valueToTree(this.getPorts()));
            }
            if (this.getTasks() != null) {
                data.set("tasks", om.valueToTree(this.getTasks()));
            }
            if (this.getVscodeExtensions() != null) {
                data.set("vscodeExtensions", om.valueToTree(this.getVscodeExtensions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.GitpodOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GitpodOptions.Jsii$Proxy that = (GitpodOptions.Jsii$Proxy) o;

            if (this.prebuilds != null ? !this.prebuilds.equals(that.prebuilds) : that.prebuilds != null) return false;
            if (this.dockerImage != null ? !this.dockerImage.equals(that.dockerImage) : that.dockerImage != null) return false;
            if (this.ports != null ? !this.ports.equals(that.ports) : that.ports != null) return false;
            if (this.tasks != null ? !this.tasks.equals(that.tasks) : that.tasks != null) return false;
            return this.vscodeExtensions != null ? this.vscodeExtensions.equals(that.vscodeExtensions) : that.vscodeExtensions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.prebuilds != null ? this.prebuilds.hashCode() : 0;
            result = 31 * result + (this.dockerImage != null ? this.dockerImage.hashCode() : 0);
            result = 31 * result + (this.ports != null ? this.ports.hashCode() : 0);
            result = 31 * result + (this.tasks != null ? this.tasks.hashCode() : 0);
            result = 31 * result + (this.vscodeExtensions != null ? this.vscodeExtensions.hashCode() : 0);
            return result;
        }
    }
}
